==> comm-0.2.2-gh.tar.gz: comm-0.2.2/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.2.2

([Full Changelog](https://github.com/ipython/comm/compare/v0.2.1...76149e7ee0f331772c964ae86cdb8bafebe6dfa2))

### Maintenance and upkeep improvements

- Update Release Scripts [#27](https://github.com/ipython/comm/pull/27) ([@blink1073](https://github.com/blink1073))

### Other merged PRs

- chore: update pre-commit hooks [#26](https://github.com/ipython/comm/pull/26) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ipython/comm/graphs/contributors?from=2024-01-02&to=2024-03-12&type=c))

[@blink1073](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Ablink1073+updated%3A2024-01-02..2024-03-12&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Apre-commit-ci+updated%3A2024-01-02..2024-03-12&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.2.1

([Full Changelog](https://github.com/ipython/comm/compare/v0.2.0...46e07dc298d19c1b7ade765d0a435f794e69a020))

### Maintenance and upkeep improvements

- Update ruff config [#23](https://github.com/ipython/comm/pull/23) ([@blink1073](https://github.com/blink1073))

### Other merged PRs

- chore: update pre-commit hooks [#25](https://github.com/ipython/comm/pull/25) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Prevent exception spam during interpreter teardown [#24](https://github.com/ipython/comm/pull/24) ([@apmorton](https://github.com/apmorton))
- chore: update pre-commit hooks [#22](https://github.com/ipython/comm/pull/22) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- chore: update pre-commit hooks [#21](https://github.com/ipython/comm/pull/21) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ipython/comm/graphs/contributors?from=2023-11-06&to=2024-01-02&type=c))

[@apmorton](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Aapmorton+updated%3A2023-11-06..2024-01-02&type=Issues) | [@blink1073](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Ablink1073+updated%3A2023-11-06..2024-01-02&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Apre-commit-ci+updated%3A2023-11-06..2024-01-02&type=Issues)

## 0.2.0

([Full Changelog](https://github.com/ipython/comm/compare/v0.1.4...5e4ad3166b80feba3f74ad074b7b5f98d7a99439))

### Maintenance and upkeep improvements

- Add downstream checks [#20](https://github.com/ipython/comm/pull/20) ([@blink1073](https://github.com/blink1073))
- Adopt sp-repo-review [#19](https://github.com/ipython/comm/pull/19) ([@blink1073](https://github.com/blink1073))

### Other merged PRs

- Bump actions/checkout from 3 to 4 [#17](https://github.com/ipython/comm/pull/17) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ipython/comm/graphs/contributors?from=2023-08-02&to=2023-11-06&type=c))

[@blink1073](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Ablink1073+updated%3A2023-08-02..2023-11-06&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Adependabot+updated%3A2023-08-02..2023-11-06&type=Issues)

## 0.1.4

([Full Changelog](https://github.com/ipython/comm/compare/v0.1.3...136c099e4fb1cc83040661796ad7ea349af04be8))

### Improvements

- Loosen dependency on traitlet so it is available in python 3.6 [#16](https://github.com/ipython/comm/pull/16) ([@vincent-grosbois](https://github.com/vincent-grosbois))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ipython/comm/graphs/contributors?from=2023-03-22&to=2023-08-02&type=c))

[@martinRenou](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3AmartinRenou+updated%3A2023-03-22..2023-08-02&type=Issues) | [@vincent-grosbois](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Avincent-grosbois+updated%3A2023-03-22..2023-08-02&type=Issues)

## 0.1.3

([Full Changelog](https://github.com/ipython/comm/compare/0.1.2...309b8295ca950a9ca9bdc0daa796215d72a7cb09))

### Maintenance and upkeep improvements

- Adopt linters and releaser [#12](https://github.com/ipython/comm/pull/12) ([@blink1073](https://github.com/blink1073))

### Other merged PRs

- feat: provide a default implementation [#13](https://github.com/ipython/comm/pull/13) ([@maartenbreddels](https://github.com/maartenbreddels))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ipython/comm/graphs/contributors?from=2022-12-08&to=2023-03-22&type=c))

[@blink1073](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Ablink1073+updated%3A2022-12-08..2023-03-22&type=Issues) | [@maartenbreddels](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Amaartenbreddels+updated%3A2022-12-08..2023-03-22&type=Issues)

## 0.1.2

Initial release

==> comm-0.2.3.gh.tar.gz: comm-0.2.3/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.2.3

([Full Changelog](https://github.com/ipython/comm/compare/v0.2.2...ec3eb438c07314b47c057c1cc3ce5fe43c294e90))

### Merged PRs

- Remove `traitlets` dependency [#32](https://github.com/ipython/comm/pull/32) ([@davidbrochart](https://github.com/davidbrochart))
- Add Security.md file. [#29](https://github.com/ipython/comm/pull/29) ([@Carreau](https://github.com/Carreau))
- pre-commit updates and fixes [#28](https://github.com/ipython/comm/pull/28) ([@Carreau](https://github.com/Carreau))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ipython/comm/graphs/contributors?from=2024-03-12&to=2025-07-25&type=c))

[@Carreau](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3ACarreau+updated%3A2024-03-12..2025-07-25&type=Issues) | [@davidbrochart](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Adavidbrochart+updated%3A2024-03-12..2025-07-25&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.2.2

([Full Changelog](https://github.com/ipython/comm/compare/v0.2.1...76149e7ee0f331772c964ae86cdb8bafebe6dfa2))

### Maintenance and upkeep improvements

- Update Release Scripts [#27](https://github.com/ipython/comm/pull/27) ([@blink1073](https://github.com/blink1073))

### Other merged PRs

- chore: update pre-commit hooks [#26](https://github.com/ipython/comm/pull/26) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ipython/comm/graphs/contributors?from=2024-01-02&to=2024-03-12&type=c))

[@blink1073](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Ablink1073+updated%3A2024-01-02..2024-03-12&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Apre-commit-ci+updated%3A2024-01-02..2024-03-12&type=Issues)

## 0.2.1

([Full Changelog](https://github.com/ipython/comm/compare/v0.2.0...46e07dc298d19c1b7ade765d0a435f794e69a020))

### Maintenance and upkeep improvements

- Update ruff config [#23](https://github.com/ipython/comm/pull/23) ([@blink1073](https://github.com/blink1073))

### Other merged PRs

- chore: update pre-commit hooks [#25](https://github.com/ipython/comm/pull/25) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Prevent exception spam during interpreter teardown [#24](https://github.com/ipython/comm/pull/24) ([@apmorton](https://github.com/apmorton))
- chore: update pre-commit hooks [#22](https://github.com/ipython/comm/pull/22) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- chore: update pre-commit hooks [#21](https://github.com/ipython/comm/pull/21) ([@pre-commit-ci](https://github.com/pre-commit-ci))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ipython/comm/graphs/contributors?from=2023-11-06&to=2024-01-02&type=c))

[@apmorton](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Aapmorton+updated%3A2023-11-06..2024-01-02&type=Issues) | [@blink1073](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Ablink1073+updated%3A2023-11-06..2024-01-02&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Apre-commit-ci+updated%3A2023-11-06..2024-01-02&type=Issues)

## 0.2.0

([Full Changelog](https://github.com/ipython/comm/compare/v0.1.4...5e4ad3166b80feba3f74ad074b7b5f98d7a99439))

### Maintenance and upkeep improvements

- Add downstream checks [#20](https://github.com/ipython/comm/pull/20) ([@blink1073](https://github.com/blink1073))
- Adopt sp-repo-review [#19](https://github.com/ipython/comm/pull/19) ([@blink1073](https://github.com/blink1073))

### Other merged PRs

- Bump actions/checkout from 3 to 4 [#17](https://github.com/ipython/comm/pull/17) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ipython/comm/graphs/contributors?from=2023-08-02&to=2023-11-06&type=c))

[@blink1073](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Ablink1073+updated%3A2023-08-02..2023-11-06&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Adependabot+updated%3A2023-08-02..2023-11-06&type=Issues)

## 0.1.4

([Full Changelog](https://github.com/ipython/comm/compare/v0.1.3...136c099e4fb1cc83040661796ad7ea349af04be8))

### Improvements

- Loosen dependency on traitlet so it is available in python 3.6 [#16](https://github.com/ipython/comm/pull/16) ([@vincent-grosbois](https://github.com/vincent-grosbois))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ipython/comm/graphs/contributors?from=2023-03-22&to=2023-08-02&type=c))

[@martinRenou](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3AmartinRenou+updated%3A2023-03-22..2023-08-02&type=Issues) | [@vincent-grosbois](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Avincent-grosbois+updated%3A2023-03-22..2023-08-02&type=Issues)

## 0.1.3

([Full Changelog](https://github.com/ipython/comm/compare/0.1.2...309b8295ca950a9ca9bdc0daa796215d72a7cb09))

### Maintenance and upkeep improvements

- Adopt linters and releaser [#12](https://github.com/ipython/comm/pull/12) ([@blink1073](https://github.com/blink1073))

### Other merged PRs

- feat: provide a default implementation [#13](https://github.com/ipython/comm/pull/13) ([@maartenbreddels](https://github.com/maartenbreddels))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ipython/comm/graphs/contributors?from=2022-12-08&to=2023-03-22&type=c))

[@blink1073](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Ablink1073+updated%3A2022-12-08..2023-03-22&type=Issues) | [@maartenbreddels](https://github.com/search?q=repo%3Aipython%2Fcomm+involves%3Amaartenbreddels+updated%3A2022-12-08..2023-03-22&type=Issues)

## 0.1.2

Initial release
